@@ -19,14 +19,15 @@
 
 #include "abstractimportexportjob.h"
 #include "archivestorage.h"
+#include "backupresourcefilejobbase.h"
+#include "backupresourcefilejobimpl.h"
 #include "importexportprogressindicatorbase.h"
+#include "storeresourcejob.h"
 #include "synchronizeresourcejob.h"
 
-#include "MailCommon/MailUtil"
-
 #include <PimCommonAkonadi/CreateResource>
+#include <AkonadiCore/AgentInstance>
 
-#include <KIdentityManagement/kidentitymanagement/identitymanager.h>
 #include <KZip>
 #include <QTemporaryDir>
 #include <KLocalizedString>
@@ -37,6 +38,7 @@
 #include <QDir>
 #include <QStandardPaths>
 #include <QCoreApplication>
+#include <KConfigGroup>
 
 int AbstractImportExportJob::sArchiveVersion = -1;
 
@@ -44,9 +46,7 @@ AbstractImportExportJob::AbstractImportExportJob(QObject *parent, ArchiveStorage
     : QObject(parent)
     , mTypeSelected(typeSelected)
     , mArchiveStorage(archiveStorage)
-    , mIdentityManager(KIdentityManagement::IdentityManager::self())
     , mNumberOfStep(numberOfStep)
-    , mIndex(-1)
     , mImportExportProgressIndicator(new ImportExportProgressIndicatorBase(this))
 {
     mImportExportProgressIndicator->setNumberOfStep(numberOfStep);
@@ -151,13 +151,13 @@ void AbstractImportExportJob::overwriteDirectory(const QString &path, const KArc
         if (overwriteDirectoryMessageBox(path)) {
             const KArchiveDirectory *dirEntry = static_cast<const KArchiveDirectory *>(entry);
             if (!dirEntry->copyTo(path)) {
-                qCDebug(PIMDATAEXPORTERCORE_LOG) << "directory cannot overwrite to " << path;
+                qCWarning(PIMDATAEXPORTERCORE_LOG) << "directory cannot overwrite to " << path;
             }
         }
     } else {
         const KArchiveDirectory *dirEntry = static_cast<const KArchiveDirectory *>(entry);
         if (dirEntry->copyTo(path)) {
-            qCDebug(PIMDATAEXPORTERCORE_LOG) << "directory cannot overwrite to " << path;
+            qCWarning(PIMDATAEXPORTERCORE_LOG) << "directory cannot overwrite to " << path;
         }
     }
 }
@@ -189,7 +189,7 @@ void AbstractImportExportJob::storeArchiveInfoResources(const KArchiveDirectory
 
             if (lst.count() >= 2) {
                 const QString archPath(prefix + QLatin1Char('/') + entryName + QLatin1Char('/'));
-                resourceFiles files;
+                ResourceFiles files;
                 for (const QString &name : lst) {
                     if (isAConfigFile(name)) {
                         files.akonadiConfigFile = archPath + name;
@@ -202,10 +202,11 @@ void AbstractImportExportJob::storeArchiveInfoResources(const KArchiveDirectory
                 files.debug();
                 mListResourceFile.append(files);
             } else {
-                qCDebug(PIMDATAEXPORTERCORE_LOG) << " Problem in archive. number of file " << lst.count();
+                qCWarning(PIMDATAEXPORTERCORE_LOG) << " Problem in archive. number of file " << lst.count();
             }
         }
     }
+    std::sort(mListResourceFile.begin(), mListResourceFile.end());
 }
 
 bool AbstractImportExportJob::isAConfigFile(const QString &name) const
@@ -242,31 +243,6 @@ qint64 AbstractImportExportJob::convertRealPathToCollection(KConfigGroup &group,
     return colId;
 }
 
-void AbstractImportExportJob::convertRealPathToCollectionList(KConfigGroup &group, const QString &currentKey, bool addCollectionPrefix)
-{
-    if (group.hasKey(currentKey)) {
-        const QStringList listExpension = group.readEntry(currentKey, QStringList());
-        QStringList result;
-        if (!listExpension.isEmpty()) {
-            for (const QString &collection : listExpension) {
-                const Akonadi::Collection::Id id = convertPathToId(collection);
-                if (id != -1) {
-                    if (addCollectionPrefix) {
-                        result << QStringLiteral("c%1").arg(id);
-                    } else {
-                        result << QStringLiteral("%1").arg(id);
-                    }
-                }
-            }
-            if (result.isEmpty()) {
-                group.deleteEntry(currentKey);
-            } else {
-                group.writeEntry(currentKey, result);
-            }
-        }
-    }
-}
-
 Akonadi::Collection::Id AbstractImportExportJob::convertPathToId(const QString &path)
 {
     if (path.isEmpty()) {
@@ -276,7 +252,7 @@ Akonadi::Collection::Id AbstractImportExportJob::convertPathToId(const QString &
     if (val != -1) {
         return val;
     }
-    const Akonadi::Collection::Id id = MailCommon::Util::convertFolderPathToCollectionId(path);
+    const Akonadi::Collection::Id id = convertFolderPathToCollectionId(path);
     if (id != -1) {
         mHashConvertPathCollectionId.insert(path, id);
     }
@@ -311,11 +287,11 @@ void AbstractImportExportJob::copyToFile(const KArchiveFile *archivefile, const
     const QString copyToDirName(mTempDirName + QLatin1Char('/') + prefix);
     const bool created = dir.mkpath(copyToDirName);
     if (!created) {
-        qCDebug(PIMDATAEXPORTERCORE_LOG) << " directory :" << prefix << " not created";
+        qCWarning(PIMDATAEXPORTERCORE_LOG) << " directory :" << prefix << " not created";
     }
 
     if (!archivefile->copyTo(copyToDirName)) {
-        qCDebug(PIMDATAEXPORTERCORE_LOG) << "file " << filename << " can not copy to " << dest;
+        qCWarning(PIMDATAEXPORTERCORE_LOG) << "file " << filename << " can not copy to " << dest;
     }
     QFile file;
     file.setFileName(copyToDirName + QLatin1Char('/') + filename);
@@ -337,38 +313,15 @@ void AbstractImportExportJob::copyToFile(const KArchiveFile *archivefile, const
     }
 }
 
-void AbstractImportExportJob::backupResourceFile(const Akonadi::AgentInstance &agent, const QString &defaultPath)
+void AbstractImportExportJob::backupResourceFile(const QString &identifier, const QString &defaultPath)
 {
-    const QString identifier = agent.identifier();
-    const QString archivePath = defaultPath + identifier + QLatin1Char('/');
-
-    QString url = Utils::resourcePath(agent);
-    if (!url.isEmpty()) {
-        QFileInfo fi(url);
-        QString filename = fi.fileName();
-        const bool fileAdded = archive()->addLocalFile(url, archivePath + filename);
-        if (fileAdded) {
-            const QString errorStr = Utils::storeResources(archive(), identifier, archivePath);
-            if (!errorStr.isEmpty()) {
-                Q_EMIT error(errorStr);
-            }
-            Q_EMIT info(i18n("\"%1\" was backed up.", filename));
-
-            url = Akonadi::ServerManager::agentConfigFilePath(identifier);
-            if (!url.isEmpty()) {
-                fi = QFileInfo(url);
-                filename = fi.fileName();
-                const bool fileAdded = archive()->addLocalFile(url, archivePath + filename);
-                if (fileAdded) {
-                    Q_EMIT info(i18n("\"%1\" was backed up.", filename));
-                } else {
-                    Q_EMIT error(i18n("\"%1\" file cannot be added to backup file.", filename));
-                }
-            }
-        } else {
-            Q_EMIT error(i18n("\"%1\" file cannot be added to backup file.", filename));
-        }
-    }
+    BackupResourceFileJobImpl *job = new BackupResourceFileJobImpl(this);
+    job->setDefaultPath(defaultPath);
+    job->setIdentifier(identifier);
+    job->setZip(archive());
+    connect(job, &BackupResourceFileJobImpl::error, this, &AbstractImportExportJob::error);
+    connect(job, &BackupResourceFileJobImpl::info, this, &AbstractImportExportJob::info);
+    job->start();
 }
 
 QStringList AbstractImportExportJob::restoreResourceFile(const QString &resourceBaseName, const QString &defaultPath, const QString &storePath, bool overwriteResources)
@@ -381,15 +334,15 @@ QStringList AbstractImportExportJob::restoreResourceFile(const QString &resource
         const QString copyToDirName(mTempDirName + QLatin1Char('/') + defaultPath);
         QDir().mkpath(copyToDirName);
 
-        for (int i = 0; i < mListResourceFile.size(); ++i) {
-            resourceFiles value = mListResourceFile.at(i);
+        for (int i = 0, total = mListResourceFile.size(); i < total; ++i) {
+            ResourceFiles value = mListResourceFile.at(i);
             QMap<QString, QVariant> settings;
             if (value.akonadiConfigFile.contains(resourceBaseName + QLatin1Char('_'))) {
                 const KArchiveEntry *fileResouceEntry = mArchiveDirectory->entry(value.akonadiConfigFile);
                 if (fileResouceEntry && fileResouceEntry->isFile()) {
                     const KArchiveFile *file = static_cast<const KArchiveFile *>(fileResouceEntry);
                     if (!file->copyTo(copyToDirName)) {
-                        qCDebug(PIMDATAEXPORTERCORE_LOG) << "file " << value.akonadiConfigFile << " can not copy to " << copyToDirName;
+                        qCWarning(PIMDATAEXPORTERCORE_LOG) << "file " << value.akonadiConfigFile << " can not copy to " << copyToDirName;
                     }
                     QString resourceName(file->name());
 
@@ -399,18 +352,13 @@ QStringList AbstractImportExportJob::restoreResourceFile(const QString &resource
 
                     KSharedConfig::Ptr resourceConfig = KSharedConfig::openConfig(copyToDirName + QLatin1Char('/') + resourceName);
 
-                    QString newUrl;
-                    if (overwriteResources) {
-                        newUrl = Utils::resourcePath(resourceConfig);
-                    } else {
-                        newUrl = Utils::adaptResourcePath(resourceConfig, storePath);
-                    }
+                    QString newUrl = adaptNewResourceUrl(overwriteResources, resourceConfig, storePath);
                     const QString dataFile = value.akonadiResources;
                     const KArchiveEntry *dataResouceEntry = mArchiveDirectory->entry(dataFile);
                     if (dataResouceEntry->isFile()) {
                         const KArchiveFile *file = static_cast<const KArchiveFile *>(dataResouceEntry);
                         if (!file->copyTo(newUrl)) {
-                            qCDebug(PIMDATAEXPORTERCORE_LOG) << "file " << dataFile << " can not copy to " << newUrl;
+                            qCWarning(PIMDATAEXPORTERCORE_LOG) << "file " << dataFile << " can not copy to " << newUrl;
                         }
                     }
                     settings.insert(QStringLiteral("Path"), newUrl);
@@ -429,7 +377,7 @@ QStringList AbstractImportExportJob::restoreResourceFile(const QString &resource
 
                     addSpecificResourceSettings(resourceConfig, resourceBaseName, settings);
 
-                    const QString newResource = mCreateResource->createResource(resourceBaseName, filename, settings);
+                    const QString newResource = createResource(resourceBaseName, filename, settings);
                     infoAboutNewResource(newResource);
                     resourceToSync << newResource;
                     qCDebug(PIMDATAEXPORTERCORE_LOG) << " newResource" << newResource;
@@ -439,6 +387,7 @@ QStringList AbstractImportExportJob::restoreResourceFile(const QString &resource
         Q_EMIT info(i18n("Resources restored."));
     } else {
         Q_EMIT error(i18n("No resources files found."));
+        qDebug() << " resourceBaseName " << resourceBaseName;
     }
     return resourceToSync;
 }
@@ -452,7 +401,7 @@ bool AbstractImportExportJob::copyArchiveFileTo(const KArchiveFile *file, const
 {
     const bool result = file->copyTo(destination);
     if (!result) {
-        qCDebug(PIMDATAEXPORTERCORE_LOG) << "file " << file->name() << " can not copy to " << destination;
+        qCWarning(PIMDATAEXPORTERCORE_LOG) << "file " << file->name() << " can not copy to " << destination;
     }
     return result;
 }
@@ -460,7 +409,7 @@ bool AbstractImportExportJob::copyArchiveFileTo(const KArchiveFile *file, const
 void AbstractImportExportJob::extractZipFile(const KArchiveFile *file, const QString &source, const QString &destination, bool isStoredAsZippedArchive)
 {
     if (!file->copyTo(source)) {
-        qCDebug(PIMDATAEXPORTERCORE_LOG) << "file " << file->name() << " can not copy to " << source;
+        qCWarning(PIMDATAEXPORTERCORE_LOG) << "file " << file->name() << " can not copy to " << source;
     }
     QDir dest(destination);
     if (!dest.exists()) {
@@ -637,14 +586,6 @@ void AbstractImportExportJob::importDataSubdirectory(const QString &subdirectory
     }
 }
 
-void AbstractImportExportJob::convertCollectionStrToAkonadiId(const KSharedConfig::Ptr &config, const QString &groupName, const QString &key)
-{
-    if (config->hasGroup(groupName)) {
-        KConfigGroup eventGroup = config->group(groupName);
-        (void)convertRealPathToCollection(eventGroup, key, false);
-    }
-}
-
 void AbstractImportExportJob::convertCollectionListStrToAkonadiId(const KSharedConfig::Ptr &config, const QString &groupName, const QString &key, bool addCollectionPrefix)
 {
     if (config->hasGroup(groupName)) {
@@ -652,3 +593,33 @@ void AbstractImportExportJob::convertCollectionListStrToAkonadiId(const KSharedC
         convertRealPathToCollectionList(group, key, addCollectionPrefix);
     }
 }
+
+void AbstractImportExportJob::convertRealPathToCollectionList(KConfigGroup &group, const QString &currentKey, bool addCollectionPrefix)
+{
+    if (group.hasKey(currentKey)) {
+        const QStringList listExpension = group.readEntry(currentKey, QStringList());
+        QStringList result;
+        if (!listExpension.isEmpty()) {
+            for (const QString &collection : listExpension) {
+                const Akonadi::Collection::Id id = convertPathToId(collection);
+                if (id != -1) {
+                    if (addCollectionPrefix) {
+                        result << QStringLiteral("c%1").arg(id);
+                    } else {
+                        result << QStringLiteral("%1").arg(id);
+                    }
+                }
+            }
+            if (result.isEmpty()) {
+                group.deleteEntry(currentKey);
+            } else {
+                group.writeEntry(currentKey, result);
+            }
+        }
+    }
+}
+
+void AbstractImportExportJob::setTempDirName(const QString &tempDirName)
+{
+    mTempDirName = tempDirName;
+}
