@@ -33,11 +33,6 @@ class KZip;
 class KArchiveFile;
 class KArchiveEntry;
 
-namespace KIdentityManagement {
-class Identity;
-class IdentityManager;
-}
-
 namespace PimCommon {
 class CreateResource;
 }
@@ -60,6 +55,9 @@ public:
 
     ImportExportProgressIndicatorBase *importExportProgressIndicator() const;
 
+    //Only for test
+    void setTempDirName(const QString &tempDirName);
+
 Q_SIGNALS:
     void info(const QString &);
     void error(const QString &);
@@ -74,13 +72,12 @@ protected:
 protected:
     Q_REQUIRED_RESULT bool copyArchiveFileTo(const KArchiveFile *file, const QString &destination);
     void initializeListStep();
-    void startSynchronizeResources(const QStringList &listResourceToSync);
+    virtual void startSynchronizeResources(const QStringList &listResourceToSync);
     void infoAboutNewResource(const QString &resourceName);
     void copyToDirectory(const KArchiveEntry *entry, const QString &dest);
     void extractZipFile(const KArchiveFile *file, const QString &source, const QString &destination, bool isStoredAsZippedArchive = true);
 
     Q_REQUIRED_RESULT qint64 convertRealPathToCollection(KConfigGroup &group, const QString &currentKey, bool addCollectionPrefix = false);
-    void convertRealPathToCollectionList(KConfigGroup &group, const QString &currentKey, bool addCollectionPrefix = true);
     void copyToFile(const KArchiveFile *archivefile, const QString &dest, const QString &filename, const QString &prefix);
     void initializeImportJob();
     void backupFile(const QString &filename, const QString &path, const QString &storedName);
@@ -91,17 +88,19 @@ protected:
     Q_REQUIRED_RESULT int mergeConfigMessageBox(const QString &configName) const;
     Q_REQUIRED_RESULT bool overwriteConfigMessageBox(const QString &configName) const;
     Q_REQUIRED_RESULT Akonadi::Collection::Id convertPathToId(const QString &path);
-    void backupResourceFile(const Akonadi::AgentInstance &agent, const QString &defaultPath);
+
+    void backupResourceFile(const QString &agentIdentifier, const QString &defaultPath);
+
     Q_REQUIRED_RESULT QStringList restoreResourceFile(const QString &resourceName, const QString &defaultPath, const QString &storePath, bool overwriteResources = false);
     virtual void addSpecificResourceSettings(const KSharedConfig::Ptr &resourceConfig, const QString &resourceName, QMap<QString, QVariant> &settings);
     void restoreConfigFile(const QString &configNameStr);
-    bool overwriteDirectoryMessageBox(const QString &directory) const;
+    Q_REQUIRED_RESULT bool overwriteDirectoryMessageBox(const QString &directory) const;
     void overwriteDirectory(const QString &path, const KArchiveEntry *entry);
     virtual bool isAConfigFile(const QString &name) const;
     void searchAllFiles(const KArchiveDirectory *dir, const QString &prefix, const QString &searchEntryName);
     void storeArchiveInfoResources(const KArchiveDirectory *dir, const QString &prefix);
 
-    KZip *archive() const;
+    Q_REQUIRED_RESULT KZip *archive() const;
 
     void increaseProgressDialog();
     void createProgressDialog(const QString &title = QString());
@@ -110,24 +109,28 @@ protected:
     void storeDirectory(const QString &subDirectory);
     void importDataSubdirectory(const QString &subdirectoryRelativePath);
 
+    void convertCollectionListStrToAkonadiId(const KSharedConfig::Ptr &config, const QString &groupName, const QString &key, bool addCollectionPrefix);
+    void convertRealPathToCollectionList(KConfigGroup &group, const QString &currentKey, bool addCollectionPrefix = true);
+    virtual Q_REQUIRED_RESULT Akonadi::Collection::Id convertFolderPathToCollectionId(const QString &path) = 0;
+    virtual QString adaptNewResourceUrl(bool overwriteResources, const KSharedConfig::Ptr &resourceConfig, const QString &storePath) = 0;
+    virtual Q_REQUIRED_RESULT QString createResource(const QString &resources, const QString &name, const QMap<QString, QVariant> &settings, bool synchronizeTree = false) = 0;
+
     QHash<QString, Akonadi::Collection::Id> mHashConvertPathCollectionId;
-    QVector<resourceFiles> mListResourceFile;
+    QVector<ResourceFiles> mListResourceFile;
 
     QString mTempDirName;
     Utils::StoredTypes mTypeSelected;
     ArchiveStorage *mArchiveStorage = nullptr;
-    KIdentityManagement::IdentityManager *mIdentityManager = nullptr;
     QTemporaryDir *mTempDir = nullptr;
     const KArchiveDirectory *mArchiveDirectory = nullptr;
     int mNumberOfStep = -1;
     PimCommon::CreateResource *mCreateResource = nullptr;
     QStringList mAgentPaths;
     QVector<Utils::StoredType> mListStep;
+    QVector<Utils::AkonadiInstanceInfo> mAkonadiInstanceInfo;
     int mIndex = -1;
     static int sArchiveVersion;
 
-    void convertCollectionStrToAkonadiId(const KSharedConfig::Ptr &config, const QString &groupName, const QString &key);
-    void convertCollectionListStrToAkonadiId(const KSharedConfig::Ptr &config, const QString &groupName, const QString &key, bool addCollectionPrefix);
 private:
     void slotAllResourceSynchronized();
     void slotSynchronizeInstanceDone(const QString &, const QString &identifier);
