@@ -20,9 +20,10 @@
 #ifndef ARCHIVESTORAGE_H
 #define ARCHIVESTORAGE_H
 #include <QObject>
+#include "pimdataexporter_export.h"
 class KZip;
 
-class ArchiveStorage : public QObject
+class PIMDATAEXPORTER_EXPORT ArchiveStorage : public QObject
 {
     Q_OBJECT
 public:
