@@ -41,9 +41,3 @@ void UtilsTest::shouldTestValue()
     QCOMPARE(Utils::dataPath(), QStringLiteral("data/"));
     QCOMPARE(Utils::notePath(), QStringLiteral("note/"));
 }
-
-void UtilsTest::shouldGetAgentFileName()
-{
-    const QString filename = Utils::resourcesPath() + QStringLiteral("akonadi_imap_resource_0rc");
-    QCOMPARE(Utils::agentFileName(filename), QStringLiteral("resources/agent_config_akonadi_imap_resource_0"));
-}
