@@ -25,6 +25,10 @@
 #include <QApplication>
 #include <Kdelibs4ConfigMigrator>
 #include <KCrash>
+#ifdef WITH_KUSERFEEDBACK
+#include "userfeedback/pimdataexporteduserfeedbackprovider.h"
+#include <KUserFeedback/Provider>
+#endif
 
 int main(int argc, char *argv[])
 {
@@ -45,7 +49,14 @@ int main(int argc, char *argv[])
 
     PimDataCommandLineOption parser;
     parser.createParser(app);
-
+#ifdef WITH_KUSERFEEDBACK
+    if (parser.parseUserFeedback()) {
+        PimDataExportedUserFeedbackProvider *provider = new PimDataExportedUserFeedbackProvider;
+        QTextStream(stdout) << provider->describeDataSources() << '\n';
+        delete provider;
+        return 0;
+    }
+#endif
     KDBusService service(KDBusService::Unique);
 
     PimDataExporterWindow *backupMailWin = new PimDataExporterWindow();
