@@ -37,7 +37,7 @@
 #include <MailCommon/MailKernel>
 #include <MailCommon/FilterManager>
 
-#include "PimCommon/PimUtil"
+#include <PimCommon/PimUtil>
 
 #include <AkonadiWidgets/ControlGui>
 
@@ -264,7 +264,7 @@ void PimDataExporterWindow::slotUpdateActions(bool inAction)
 void PimDataExporterWindow::slotRestoreFile(const QUrl &url)
 {
     if (!url.isEmpty()) {
-        loadData(url.path());
+        loadData(url.toLocalFile());
     }
 }
 
